MODULE dom_oce
   !!======================================================================
   !!                       ***  MODULE dom_oce  ***
   !! ** Purpose :   Define in memory all the ocean space domain variables
   !!======================================================================
   !! History :  1.0  !  05-10  (A. Beckmann, G. Madec)  reactivate s-coordinate 
   !!----------------------------------------------------------------------
   !! NEMO/OPA 2.4 , LOCEAN-IPSL (2007) 
   !! $Id:$ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------
   USE par_oce      ! ocean parameters

   IMPLICIT NONE
   PUBLIC           ! allows the acces to par_oce when dom_oce is used
   !                ! exception to coding rules... to be suppressed ???

   !!----------------------------------------------------------------------
   !! space domain parameters
   !! -----------------------
   LOGICAL, PUBLIC ::   lzoom      =  .FALSE.      !: zoom flag
   LOGICAL, PUBLIC ::   lzoom_e    =  .FALSE.      !: East  zoom type flag
   LOGICAL, PUBLIC ::   lzoom_w    =  .FALSE.      !: West  zoom type flag
   LOGICAL, PUBLIC ::   lzoom_s    =  .FALSE.      !: South zoom type flag
   LOGICAL, PUBLIC ::   lzoom_n    =  .FALSE.      !: North zoom type flag
   LOGICAL, PUBLIC ::   lzoom_arct =  .FALSE.      !: ORCA    arctic zoom flag
   LOGICAL, PUBLIC ::   lzoom_anta =  .FALSE.      !: ORCA antarctic zoom flag

   !                                              !!! namdom : space domain (bathymetry, mesh)
   INTEGER, PUBLIC ::   ntopo   =  0               !: = 0/1 ,compute/read the bathymetry file
   INTEGER, PUBLIC ::   ngrid   =  0               !: = 0/1, compute/read the horizontal mesh file
   INTEGER, PUBLIC ::   nmsh    =  0               !: = 1 create a mesh-mask file

   !                                              !!! domain parameters linked to mpp
   INTEGER, PUBLIC ::   nperio                     !: type of lateral boundary condition
   INTEGER, PUBLIC ::   nimpp , njmpp              !: i- & j-indexes for mpp-subdomain left bottom
   INTEGER, PUBLIC ::   nreci , nrecj              !: overlap region in i and j
   INTEGER, PUBLIC ::   nproc                      !: number for local processor
   INTEGER, PUBLIC ::   narea                      !: number for local area
   INTEGER, PUBLIC ::   nbondi, nbondj             !: mark of i- and j-direction local boundaries
   INTEGER, PUBLIC ::   npolj                      !: north fold mark (0, 3 or 4)
   INTEGER, PUBLIC ::   nlci  , nlcj               !: i- & j-dimensions of the local subdomain
   INTEGER, PUBLIC ::   nldi  , nlei               !: first and last indoor i- and j-indexes
   INTEGER, PUBLIC ::   nldj  , nlej               !:
   INTEGER, PUBLIC ::   noea  , nowe               !: index of the local neighboring processors in
   INTEGER, PUBLIC ::   noso  , nono               !: east, west, south and north directions
   INTEGER, PUBLIC ::   npne  , npnw               !: index of north east and north west processor
   INTEGER, PUBLIC ::   npse  , npsw               !: index of south east and south west processor
   INTEGER, PUBLIC ::   nbne  , nbnw               !: logical of north east & north west processor
   INTEGER, PUBLIC ::   nbse  , nbsw               !: logical of south east & south west processor
   INTEGER, PUBLIC ::   nidom                      !: ???

   INTEGER, PUBLIC, DIMENSION(jpi)    ::   mig        !: local  ==> global  domain i-indice
   INTEGER, PUBLIC, DIMENSION(jpj)    ::   mjg        !: local  ==> global  domain j-indice
   INTEGER, PUBLIC, DIMENSION(jpidta) ::   mi0, mi1   !: global ==> local domain i-indice  (if the global indice is
   !                                                  !  not in the local domain then mi0=1 and mi1=0)
   !                                                  !!gm bug ==> other solution?
   INTEGER, PUBLIC, DIMENSION(jpjdta) ::   mj0, mj1   !: global ==> local domain j-indice  (if the global indice is
   !                                                  ! not in the local domain then mj0=1 and mj1=0)

   INTEGER, PUBLIC, DIMENSION(jpnij)  ::   nimppt, njmppt   !: i-, j-indexes for each processor
   INTEGER, PUBLIC, DIMENSION(jpnij)  ::   ibonit, ibonjt   !: i-, j- processor neighbour existence
   INTEGER, PUBLIC, DIMENSION(jpnij)  ::   nlcit , nlcjt    !: dimensions of every subdomain
   INTEGER, PUBLIC, DIMENSION(jpnij)  ::   nldit , nldjt    !: first, last indoor index for each i-domain
   INTEGER, PUBLIC, DIMENSION(jpnij)  ::   nleit , nlejt    !: first, last indoor index for each j-domain

   !!----------------------------------------------------------------------
   !! horizontal curvilinear coordinate and scale factors
   !! ---------------------------------------------------------------------

   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   glamt, glamu   !: longitude of t-, u-, v- and f-points (degre)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   glamv, glamf   !:
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   gphit, gphiu   !: latitude  of t-, u-, v- and f-points (degre)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   gphiv, gphif   !:
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   e1t  , e2t     !: horizontal scale factors at t-point (m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   e1u  , e2u     !: horizontal scale factors at u-point (m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   e1v  , e2v     !: horizontal scale factors at v-point (m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   e1f  , e2f     !: horizontal scale factors at f-point (m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   ff             !: coriolis factor (2.*omega*sin(yphi) ) (s-1)

   !!----------------------------------------------------------------------
   !! vertical coordinate and scale factors
   !! --------------------------------------
   !                                           !!* namzgr : vertical coordinate *
   LOGICAL, PUBLIC ::   ln_zco     =  .TRUE.    !: z-coordinate - full step
   LOGICAL, PUBLIC ::   ln_zps     =  .FALSE.   !: z-coordinate - partial step
   LOGICAL, PUBLIC ::   ln_sco     =  .FALSE.   !: s-coordinate or hybrid z-s coordinate
#if defined key_zco
   LOGICAL, PUBLIC, PARAMETER ::   lk_zco = .TRUE.    !: z-coordinate flag (1D arrays)
#else
   LOGICAL, PUBLIC, PARAMETER ::   lk_zco = .FALSE.   !: z-coordinate flag (3D arrays)

   !! All coordinates
   !! ---------------
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   gdep3w          !: depth of T-points (sum of e3w) (m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   gdept , gdepw   !: depth at T-W  points (m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   e3v   , e3f     !: vertical scale factors at  V--F
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   e3t   , e3u     !:                            T--U  points (m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   e3vw            !: vertical scale factors at VW--
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   e3w   , e3uw    !:                            W--UW  points (m)
#endif
#if defined key_vvl
   LOGICAL, PUBLIC, PARAMETER ::   lk_vvl = .TRUE.    !: variable grid flag

   !! All coordinates
   !! ---------------
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   gdep3w_1          !: depth of T-points (sum of e3w) (m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   gdept_1, gdepw_1  !: depth at T-W  points (m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   e3v_1  , e3f_1    !: vertical scale factors at  V--F
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   e3t_1  , e3u_1    !:                            T--U  points (m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   e3vw_1            !: vertical scale factors at VW--
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   e3w_1  , e3uw_1   !:                            W--UW  points (m)
#else
   LOGICAL, PUBLIC, PARAMETER ::   lk_vvl = .FALSE.   !: fixed grid flag
#endif
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   hur, hvr              !: inverse of u and v-points ocean depth (1/m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   hu , hv               !: depth at u- and v-points (meters)

   !! z-coordinate with full steps (also used in the other cases as reference z-coordinate)
   !! =-----------------====------
   REAL(wp), PUBLIC, DIMENSION(jpk) ::   gdept_0, gdepw_0          !: reference depth of t- and w-points (m)
   REAL(wp), PUBLIC, DIMENSION(jpk) ::   e3t_0  , e3w_0            !: reference vertical scale factors at T- & W-pts (m)

   !! z-coordinate with partial steps
   !! =-----------------=======------
   !                          !!: * namelist namdom *
   REAL(wp), PUBLIC ::   e3zps_min = 5.0_wp       !: miminum thickness for partial steps (meters)
   REAL(wp), PUBLIC ::   e3zps_rat = 0.1_wp       !: minimum thickness ration for partial steps

   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   hdept, hdepw, e3tp, e3wp   !: ???

   !! s-coordinate and hybrid z-s-coordinate
   !! =----------------======---------------
   REAL(wp), PUBLIC, DIMENSION(jpk) ::   gsigt, gsigw   !: model level depth coefficient at t-, w-levels (analytic)
   REAL(wp), PUBLIC, DIMENSION(jpk) ::   gsi3w          !: model level depth coefficient at w-level (sum of gsigw)
   REAL(wp), PUBLIC, DIMENSION(jpk) ::   esigt, esigw   !: vertical scale factor coef. at t-, w-levels

   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   hbatv , hbatf   !: ocean depth at the vertical of  V--F
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   hbatt , hbatu   !:                                 T--U  points (m)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   scosrf, scobot  !:  ocean surface and bottom topographies
   !                                                         !   (if deviating from coordinate surfaces in HYBRID)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   hifv  , hiff    !: interface depth between stretching at  V--F
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   hift  , hifu    !: and quasi-uniform spacing              T--U  points (m)

   !!----------------------------------------------------------------------
   !! masks, bathymetry
   !! -----------------

   INTEGER , PUBLIC, DIMENSION(jpi,jpj)     ::   mbathy         !: number of ocean level (=0, 1, ... , jpk-1)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj)     ::   bathy          !: ocean depth (meters)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj)     ::   tmask_i        !: interior domain T-point mask
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj)     ::   bmask          !: land/ocean mask of barotropic stream function
   REAL(wp), PUBLIC, DIMENSION(jpiglo)      ::   tpol, fpol     !: north fold mask (nperio= 3 or 4)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   vmask, fmask   !: land/ocean mask at V--F
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   tmask, umask   !:             and at V--U  points


#if defined key_noslip_accurate
   INTEGER, PUBLIC, DIMENSION(            4,jpk) ::   npcoa          !: ???
   INTEGER, PUBLIC, DIMENSION(2*(jpi+jpj),4,jpk) ::   nicoa, njcoa   !: ???
#endif

   !!----------------------------------------------------------------------
   !! time domain
   !!----------------------------------------------------------------------
   !                                        !!! * Namelist * ???
   INTEGER, PUBLIC  ::   nacc   = 0          !: = 0/1 use of the acceleration of convergence technique
   INTEGER, PUBLIC  ::   neuler              !: restart euler forward option (0=Euler)

   !                                        !!! * Namelist ??? *
   REAL(wp), PUBLIC ::   rdt    = 3600._wp   !: time step for the dynamics (and tracer if nacc=0)
   REAL(wp), PUBLIC ::   rdtmin = 3600._wp   !: minimum time step on tracers
   REAL(wp), PUBLIC ::   rdtmax = 3600._wp   !: maximum time step on tracers
   REAL(wp), PUBLIC ::   rdth   =  800._wp   !: depth variation of tracer step
   REAL(wp), PUBLIC ::   rdtbt  =   90._wp   !: barotropic time step for the dynamics (lk_dynspg_ts=T)
   REAL(wp), PUBLIC ::   atfp   =   0.1_wp   !: asselin time filter parameter
   REAL(wp), PUBLIC ::   atfp1               !: asselin time filter coeff. (atfp1= 1-2*atfp)

   REAL(wp), PUBLIC, DIMENSION(jpk) ::   rdttra   !: vertical profile of tracer time step

   !!----------------------------------------------------------------------
   !! cross land advection
   !!----------------------------------------------------------------------
   !                                        !!! * Namelist ??? *
   INTEGER, PUBLIC ::   n_cla                !: flag (0/1) for cross land advection to
      !                                      ! parameterize exchanges through straits

#if defined key_agrif
   !!----------------------------------------------------------------------
   !! agrif sponge layer
   !!----------------------------------------------------------------------
   LOGICAL, PUBLIC :: spongedoneT = .FALSE.  !: ???
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   zspe1ur, zspe2vr ,zspbtr2    !: ???
   !!----------------------------------------------------------------------
#endif

   !!======================================================================
END MODULE dom_oce
