MODULE trdmod_oce
   !!======================================================================
   !!                   ***  MODULE trdmod_oce  ***
   !! Ocean trends :   set tracer and momentum trend variables
   !!======================================================================
   !! History :  9.0  !  04-08  (C. Talandier) Original code
   !!----------------------------------------------------------------------
   USE trdicp_oce              ! ocean momentum/tracers bassin properties trends variables
   USE trdmld_oce              ! ocean active mixed layer tracers trends variables
   USE trdvor_oce              ! ocean vorticity trends variables

   IMPLICIT NONE
   PUBLIC

   !!* Namelist namtrd:  diagnostics on dynamics/tracer trends
   INTEGER , PUBLIC ::    ntrd  = 10                    !: time step frequency dynamics and tracers trends
   INTEGER , PUBLIC ::    nctls =  0                    !: control surface type for trends vertical integration
   REAL(wp), PUBLIC ::    ucf   = 1.                    !: unit conversion factor (for netCDF trends outputs)
                                                        !: =1. (=86400.) for degC/s (degC/day) and psu/s (psu/day)
   LOGICAL , PUBLIC ::    ln_trdmld_instant = .FALSE.   !: flag to diagnose inst./mean ML T/S trends
   LOGICAL , PUBLIC ::    ln_trdmld_restart = .FALSE.   !: flag to restart mixed-layer diagnostics

   !!* Control parameters
# if defined key_trdtra   ||   defined key_trdmld
   LOGICAL , PUBLIC ::   l_trdtra = .TRUE.              !: tracers  trend flag
# else
   LOGICAL , PUBLIC ::   l_trdtra = .FALSE.             !: tracers  trend flag
# endif
# if defined key_trddyn   ||   defined key_trdvor
   LOGICAL , PUBLIC ::   l_trddyn = .TRUE.              !: momentum trend flag
# else
   LOGICAL , PUBLIC ::   l_trddyn = .FALSE.             !: momentum trend flag
# endif
#if  defined key_trdtra   &&   defined key_trddyn    ||   defined key_esopa
   LOGICAL, PARAMETER ::   lk_trdtra = .TRUE.    !: tracers  trend flag
   LOGICAL, PARAMETER ::   lk_trddyn = .TRUE.    !: momentum trend flag
#elif  defined key_trdtra
   LOGICAL, PARAMETER ::   lk_trdtra = .TRUE.    !: tracers  trend flag
   LOGICAL, PARAMETER ::   lk_trddyn = .FALSE.   !: momentum trend flag
#elif  defined key_trddyn
   LOGICAL, PARAMETER ::   lk_trdtra = .FALSE.   !: tracers  trend flag
   LOGICAL, PARAMETER ::   lk_trddyn = .TRUE.    !: momentum trend flag
#else
   LOGICAL, PARAMETER ::   lk_trdtra = .FALSE.   !: tracers  trend flag
   LOGICAL, PARAMETER ::   lk_trddyn = .FALSE.   !: momentum trend flag
#endif


   !!* Active tracers trends indexes
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd = 13        !: change it when adding/removing one indice above

   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_xad =  1   !: x- horizontal advection
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_yad =  2   !: y- horizontal advection
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_zad =  3   !: z- vertical   advection
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_ldf =  4   !: lateral       diffusion
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_zdf =  5   !: vertical diffusion (Kz)
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_bbc =  6   !: Bottom Boundary Condition (geoth. flux) 
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_bbl =  7   !: Bottom Boundary Layer (diffusive/convective)
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_npc =  8   !: static instability mixing
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_dmp =  9   !: damping
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_qsr = 10   !: penetrative solar radiation
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_qns = 11   !: non solar heat flux
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_atf = 12   !: Asselin correction
   INTEGER, PUBLIC, PARAMETER ::   jpt_trd_zl1 = 13   !: first level vertical flux (lk_vvl=F)

   
   !!* Momentum trends indexes
   INTEGER, PUBLIC, PARAMETER ::   jpdyn_trd_hpg =  1   !: hydrostatic pressure gradient 
   INTEGER, PUBLIC, PARAMETER ::   jpdyn_trd_keg =  2   !: kinetic energy gradient
   INTEGER, PUBLIC, PARAMETER ::   jpdyn_trd_rvo =  3   !: relative vorticity
   INTEGER, PUBLIC, PARAMETER ::   jpdyn_trd_pvo =  4   !: planetary vorticity
   INTEGER, PUBLIC, PARAMETER ::   jpdyn_trd_ldf =  5   !: lateral diffusion
   INTEGER, PUBLIC, PARAMETER ::   jpdyn_trd_zad =  6   !: vertical advection
   INTEGER, PUBLIC, PARAMETER ::   jpdyn_trd_zdf =  7   !: vertical diffusion
   INTEGER, PUBLIC, PARAMETER ::   jpdyn_trd_spg =  8   !: surface pressure gradient
   INTEGER, PUBLIC, PARAMETER ::   jpdyn_trd_dat =  9   !: damping term
   INTEGER, PUBLIC, PARAMETER ::   jpdyn_trd_swf = 10   !: surface wind forcing
   INTEGER, PUBLIC, PARAMETER ::   jpdyn_trd_bfr = 11   !: bottom friction 

   !!----------------------------------------------------------------------
   !!  OPA 9.0 , LOCEAN-IPSL (2006) 
   !! $Header$ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!======================================================================
END MODULE trdmod_oce
