MODULE oce
   !!======================================================================
   !!                      ***  MODULE  oce  ***
   !! Ocean        :  dynamics and active tracers defined in memory 
   !!======================================================================
   !! History :   1.0  !  02-11  (G. Madec)  F90: Free form and module
   !!             2.0  !  05-11  (V. Garnier) Surface pressure gradient organization
   !!----------------------------------------------------------------------
   !! NEMO/OPA 2.0 , LOCEAN-IPSL (2007) 
   !! $Id:$ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------
   USE par_oce      ! ocean parameters

   IMPLICIT NONE
   PRIVATE


   !! Physics and algorithm flags
   !! ---------------------------
   LOGICAL, PUBLIC ::   ln_dynhpg_imp   = .FALSE.  !: semi-implicite hpg flag
   INTEGER, PUBLIC ::   nn_dynhpg_rst   = 0        !: add dynhpg implicit variables in restart ot not

   !! dynamics and tracer fields              ! before ! now    ! after  !   the after trends becomes the fields
   !! --------------------------              ! fields ! fields ! trends !   only in dyn(tra)_zdf and dyn(tra)_nxt
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   ub    ,  un    ,  ua    !: i-horizontal velocity (m/s)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   vb    ,  vn    ,  va    !: j-horizontal velocity (m/s)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::            wn             !: vertical velocity (m/s)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   rotb  ,  rotn           !: relative vorticity (1/s)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   hdivb ,  hdivn          !: horizontal divergence (1/s)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   tb    ,  tn    ,  ta    !: potential temperature (celcius)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   sb    ,  sn    ,  sa    !: salinity (psu)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   rhd                     !: in situ density anomalie rhd=(rho-rau0)/rau0
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   rhop                    !: potential volumic mass (kg/m3)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj,jpk) ::   rn2                     !: brunt-vaisala frequency (1/s2)

      !! advection scheme choice
      !! -----------------------
!!gm  only for trcadv...   be be suppressed
      CHARACTER(len=3), PUBLIC  ::   l_adv   !: 'ce2' centre scheme used
         !                                   !: 'tvd' TVD scheme used
         !                                   !: 'mus' MUSCL scheme used
         !                                   !: 'mu2' MUSCL2 scheme used

   !! surface pressure gradient
   !! -------------------------
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   spgu, spgv                  !: horizontal surface pressure gradient

   !! interpolated gradient (only used in zps case)
   !! ---------------------
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   gtu, gsu, gru               !: t-, s- and rd horizontal gradient at u- and 
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   gtv, gsv, grv               !: v-points at bottom ocean level 

   !! free surface
   !! ------------
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   sshb , sshn                 !: before, now sea surface height (meters)
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   sshu , sshv                 !: sea surface height at u- and v- point
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   sshbb, ssha                 !: before before sea surface height at t-point

#if defined key_dynspg_rl   ||   defined key_esopa
   !! rigid-lid formulation
   !! ---------------------
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   bsfb, bsfn                 !: before, now barotropic streamfunction [m3/s]
   REAL(wp), PUBLIC, DIMENSION(jpi,jpj) ::   bsfd                       !: now barotropic streamfunction trend   [m3/s2]
#endif

   !!----------------------------------------------------------------------
END MODULE oce
