MODULE par_oce
   !!======================================================================
   !!                        ***  par_oce  ***
   !! Ocean :   set the ocean parameters
   !!======================================================================
   !! History :    -   !  1991     (Imbard, Levy, Madec)  Original code
   !!             1.0  !  2004-01  (G. Madec, J.-M. Molines)  Free form and module
   !!             2.4  !  2007-11  (G. Madec)  Suppress .h90 + style with AGRIF
   !!----------------------------------------------------------------------
   !! NEMO/OPA 2.4 , LOCEAN-IPSL (2007) 
   !! $Id$ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------
   USE par_kind        ! kind parameters
   USE par_orca_r4     ! ORCA R4   configuration
   USE par_orca_r2     ! ORCA R2   configuration (including 1D or arctic/antarctic zoom)
   USE par_orca_r05    ! ORCA R05  configuration (including 1D or arctic/antarctic zoom)
   USE par_orca_r025   ! ORCA R025 configuration (including 1D or arctic/antarctic zoom)
   USE par_gyre        ! GYRE      configuration
   USE par_eel_r2      ! GYRE R2   configuration
   USE par_eel_r5      ! GYRE R5   configuration
   USE par_eel_r6      ! GYRE R6   configuration
   USE par_my_cfg      ! MY_CFG    user defined configuration (including 1D)

   IMPLICIT NONE
   PUBLIC

   !!---------------------------------------------------------------------
   !! Extra halos for mpp computing 
   !!---------------------------------------------------------------------
   INTEGER, PUBLIC, PARAMETER ::   jpr2di = 0   !: number of columns for extra outer halo (solsor only)
   INTEGER, PUBLIC, PARAMETER ::   jpr2dj = 0   !: number of rows    for extra outer halo (solsor only)
   INTEGER, PUBLIC, PARAMETER ::   jpreci = 1   !: number of columns for overlap 
   INTEGER, PUBLIC, PARAMETER ::   jprecj = 1   !: number of rows    for overlap 

#if defined key_agrif
   !!---------------------------------------------------------------------
   !!   'key_agrif'   :                                              AGRIF
   !!---------------------------------------------------------------------

   ! Configuration, and domain size are not assigned to a parameter value
   !    as they are different in mother and children models
#if defined key_mpp_dyndist 
   INTEGER, PUBLIC ::   jpni, jpnj, jpnij                      !: domain decomposition (AGRIF case)
#endif
   INTEGER, PUBLIC ::   jpi, jpj, jpim1, jpjm1, jpkm1, jpij    !: local domain size    (AGRIF case)

   !! AGRIF ghost cells
   INTEGER, PUBLIC, PARAMETER :: nbghostcells = 1                           !: ???
   INTEGER, PUBLIC            :: nbcellsx = jpiglo - 2 - 2 * nbghostcells   !: ???
   INTEGER, PUBLIC            :: nbcellsy = jpjglo - 2 - 2 * nbghostcells   !: ???

#else
   !!---------------------------------------------------------------------
   !!   Default       :                         no AGRIF: model parameters
   !!---------------------------------------------------------------------

   ! Domain decomposition (NO massively parallel computer: jpni=jpnj=1 so jpi=jpiglo and jpj=jpjglo)
   INTEGER, PUBLIC, PARAMETER ::   jpni   = 1   !: number of processors following i 
   INTEGER, PUBLIC, PARAMETER ::   jpnj   = 1   !: number of processors following j
   INTEGER, PUBLIC, PARAMETER ::   jpnij  = 1   !: nb of local domain = nb of processors ( <= jpni x jpnj )

   !! Domain Matrix size on each processor
   !!   data           domain   (jpidta,jpjdta)   defined in par_"config name" modules
   !!   global or zoom domain   (jpiglo,jpjglo)   defined in par_"config name" modules
   !!   local          domain   ( jpi  , jpj  )   defined below (= size of the domain on each processor)
   INTEGER, PARAMETER ::   jpi = ( jpiglo-2*jpreci + (jpni-1) ) / jpni + 2*jpreci   !: first  dimension
   INTEGER, PARAMETER ::   jpj = ( jpjglo-2*jprecj + (jpnj-1) ) / jpnj + 2*jprecj   !: second dimension
   INTEGER, PARAMETER ::   jpim1 = jpi - 1                                          !: inner domain indices
   INTEGER, PARAMETER ::   jpjm1 = jpj - 1                                          !: inner domain indices
   INTEGER, PARAMETER ::   jpkm1 = jpk - 1                                          !: inner domain indices
   INTEGER, PARAMETER ::   jpij  = jpi * jpj                                        !:  jpi x jpj
#endif


   !!---------------------------------------------------------------------
   !! Optimization/control flags
   !!---------------------------------------------------------------------
#if defined key_esopa
   LOGICAL, PUBLIC, PARAMETER ::   lk_esopa     = .TRUE.   !: flag to activate the all options
#else
   LOGICAL, PUBLIC, PARAMETER ::   lk_esopa     = .FALSE.  !: flag to activate the all options
#endif
#if defined key_vectopt_memory
   LOGICAL, PUBLIC, PARAMETER ::   lk_vopt_mem  = .TRUE.   !: vector optimization flag
#else
   LOGICAL, PUBLIC, PARAMETER ::   lk_vopt_mem  = .FALSE.  !: vector optimization flag
#endif
#if defined key_vectopt_loop
   LOGICAL, PUBLIC, PARAMETER ::   lk_vopt_loop = .TRUE.   !: vector optimization flag
#else
   LOGICAL, PUBLIC, PARAMETER ::   lk_vopt_loop = .FALSE.  !: vector optimization flag
#endif
#if defined key_mpp_omp
   LOGICAL, PUBLIC, PARAMETER ::   lk_jki = .TRUE.   !: j-k-i loop flag
#else
   LOGICAL, PUBLIC, PARAMETER ::   lk_jki = .FALSE.  !: k-j-i loop flag
#endif

   !!---------------------------------------------------------------------
   !! Temperature/salinity indices
   !!---------------------------------------------------------------------

   INTEGER, PARAMETER ::   jp_tem = 1   !: index of temperature in the tsb, tsns &, tsa arrays
   INTEGER, PARAMETER ::   jp_sal = 2   !: index of salinity    in the tsb, tsns &, tsa arrays


   !!======================================================================
END MODULE par_oce
