MODULE step
   !!======================================================================
   !!                       ***  MODULE step  ***
   !! Time-stepping    : manager of the ocean, tracer and ice time stepping
   !!======================================================================
   !! History :        !  1991-03  ()  Original code
   !!                  !  1991-11  (G. Madec)
   !!                  !  1992-06  (M. Imbard)  add a first output record
   !!                  !  1996-04  (G. Madec)  introduction of dynspg
   !!                  !  1996-04  (M.A. Foujols)  introduction of passive tracer
   !!             8.0  !  1997-06  (G. Madec)  new architecture of call
   !!             8.2  !  1997-06  (G. Madec, M. Imbard, G. Roullet)  free surface
   !!             8.2  !  1999-02  (G. Madec, N. Grima)  hpg implicit
   !!             8.2  !  2000-07  (J-M Molines, M. Imbard)  Open Bondary Conditions
   !!   NEMO      1.0  !  2002-06  (G. Madec)  free form, suppress macro-tasking
   !!              -   !  2004-08  (C. Talandier) New trends organization
   !!              -   !  2005-01  (C. Ethe) Add the KPP closure scheme
   !!              -   !  2005-11  (V. Garnier) Surface pressure gradient organization
   !!              -   !  2005-11  (G. Madec)  Reorganisation of tra and dyn calls
   !!             2.0  !  2006-01  (L. Debreu, C. Mazauric)  Agrif implementation
   !!              -   !  2006-07  (S. Masson)  restart using iom
   !!             2.4  !  2008-01  (G. Madec) Merge TRA-TRC
   !!----------------------------------------------------------------------
   !!   stp            : OPA system time-stepping
   !!----------------------------------------------------------------------
   USE oce             ! ocean dynamics and tracers variables
   USE dom_oce         ! ocean space and time domain variables 
   USE zdf_oce         ! ocean vertical physics variables
   USE ldftra_oce      ! ocean tracer   - trends
   USE ldfdyn_oce      ! ocean dynamics - trends
   USE cpl_oce         ! coupled ocean-atmosphere variables
   USE in_out_manager  ! I/O manager
   USE iom
   USE lbclnk

   USE daymod          ! calendar                         (day     routine)

   USE dtatem          ! ocean temperature data           (dta_tem routine)
   USE dtasal          ! ocean salinity    data           (dta_sal routine)
   USE dtasst          ! ocean sea surface temperature    (dta_sst routine)
   USE dtasss          ! ocean sea surface salinity       (dta_sss routine)
   USE taumod          ! surface stress                   (tau     routine)
   USE flxmod          ! thermohaline fluxes              (flx     routine)
   USE ocesbc          ! thermohaline fluxes              (oce_sbc routine)
   USE flxrnf          ! runoffs                          (flx_rnf routine)
   USE flxfwb          ! freshwater budget correction     (flx_fwb routine)
   USE closea          ! closed sea freshwater budget     (flx_clo routine)
   USE ocfzpt          ! surface ocean freezing point    (oc_fz_pt routine)

   USE trcstp          ! passive tracer time-stepping      (trc_stp routine)

   USE traqsr          ! solar radiation penetration      (tra_qsr routine)
   USE trasbc          ! surface boundary condition       (tra_sbc routine)
   USE trabbc          ! bottom boundary condition        (tra_bbc routine)
   USE trabbl          ! bottom boundary layer            (tra_bbl routine)
   USE tradmp          ! internal damping                 (tra_dmp routine)
   USE traadv          ! advection scheme control     (tra_adv_ctl routine)
   USE traldf          ! lateral mixing                   (tra_ldf routine)
   USE cla             ! cross land advection             (tra_cla routine)
   !   zdfkpp          ! KPP non-local tracer fluxes      (tra_kpp routine)
   USE trazdf          ! vertical mixing                  (tra_zdf routine)
   USE tranxt          ! time-stepping                    (tra_nxt routine)
   USE tranpc          ! non-penetrative convection       (tra_npc routine)

   USE eosbn2          ! equation of state                (eos_bn2 routine)

   USE dynadv          ! advection                        (dyn_adv routine)
   USE dynvor          ! vorticity term                   (dyn_vor routine)
   USE dynhpg          ! hydrostatic pressure grad.       (dyn_hpg routine)
   USE dynldf          ! lateral momentum diffusion       (dyn_ldf routine)
   USE dynzdf          ! vertical diffusion               (dyn_zdf routine)
   USE dynspg_oce      ! surface pressure gradient        (dyn_spg routine)
   USE dynspg          ! surface pressure gradient        (dyn_spg routine)
   USE dynnxt          ! time-stepping                    (dyn_nxt routine)

   USE obc_par         ! open boundary condition variables
   USE obcdta          ! open boundary condition data     (obc_dta routine)
   USE obcrst          ! open boundary cond. restart      (obc_rst routine)
   USE obcrad          ! open boundary cond. radiation    (obc_rad routine)
   USE obcspg          ! open boundary cond  spg          (obc_spg routine)

   USE divcur          ! hor. divergence and curl      (div & cur routines)
   USE cla_div         ! cross land: hor. divergence      (div_cla routine)
   USE wzvmod          ! vertical velocity                (wzv     routine)

   USE ldfslp          ! iso-neutral slopes               (ldf_slp routine)
   USE ldfeiv          ! eddy induced velocity coef.      (ldf_eiv routine)

   USE zdfbfr          ! bottom friction                  (zdf_bfr routine)
   USE zdftke          ! TKE vertical mixing              (zdf_tke routine)
   USE zdftke_jki      ! TKE vertical mixing              (zdf_tke routine)
   USE zdfkpp          ! KPP vertical mixing              (zdf_kpp routine)
   USE zdfddm          ! double diffusion mixing          (zdf_ddm routine)
   USE zdfevd          ! enhanced vertical diffusion      (zdf_evd routine)
   USE zdfric          ! Richardson vertical mixing       (zdf_ric routine)
   USE zdfmxl          ! Mixed-layer depth                (zdf_mxl routine)

   USE zpshde          ! partial step: hor. derivative     (zps_hde routine)
   USE ice_oce         ! sea-ice variable
   USE icestp          ! sea-ice time-stepping             (ice_stp routine)

   USE diawri          ! Standard run outputs             (dia_wri routine)
   USE trdicp          ! Ocean momentum/tracers trends    (trd_wri routine)
   USE trdmld          ! mixed-layer trends               (trd_mld routine)
   USE trdmld_rst      ! restart for mixed-layer trends
   USE trdmod_oce      ! ocean momentum/tracers trends
   USE trdvor          ! vorticity budget                 (trd_vor routine)
   USE diagap          ! hor. mean model-data gap         (dia_gap routine)
   USE diahdy          ! dynamic height                   (dia_hdy routine)
   USE diaptr          ! poleward transports              (dia_ptr routine)
   USE diahth          ! thermocline depth                (dia_hth routine)
   USE diafwb          ! freshwater budget                (dia_fwb routine)
   USE diaspr          ! suface pressure (rigid-lid)      (dia_spr routine)
   USE flo_oce         ! floats variables
   USE floats          ! floats computation               (flo_stp routine)

   USE stpctl          ! time stepping control            (stp_ctl routine)
   USE restart         ! ocean restart                    (rst_wri routine)
   USE cpl             ! exchanges in coupled mode        (cpl_stp routine)
   USE prtctl          ! Print control                    (prt_ctl routine)
   USE domvvl          ! variable volume                  (dom_vvl routine)

#if defined key_agrif
   USE agrif_opa_sponge ! Momemtum and tracers sponges
#endif

   IMPLICIT NONE
   PRIVATE

   PUBLIC stp            ! called by opa.F90

   !! * Substitutions
#  include "domzgr_substitute.h90"
#  include "zdfddm_substitute.h90"
   !!----------------------------------------------------------------------
   !!   OPA 9.0 , LOCEAN-IPSL (2005) 
   !! $Header$ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt) 
   !!----------------------------------------------------------------------

CONTAINS

#if defined key_agrif
   SUBROUTINE stp( )
#else
   SUBROUTINE stp( kstp )
#endif
      !!----------------------------------------------------------------------
      !!                     ***  ROUTINE stp  ***
      !!                      
      !! ** Purpose : - Time stepping of OPA (momentum and active tracer eqs.)
      !!              - Time stepping of LIM (dynamic and thermodynamic eqs.)
      !!              - Tme stepping  of TRC (passive tracer eqs.)
      !! 
      !! ** Method  : -1- Update forcings and data  
      !!              -2- Update ocean physics 
      !!              -3- Compute the t and s trends 
      !!              -4- Update t and s 
      !!              -5- Compute the momentum trends
      !!              -6- Update the horizontal velocity
      !!              -7- Compute the diagnostics variables (rd,N2, div,cur,w)
      !!              -8- Outputs and diagnostics
      !!----------------------------------------------------------------------
      !! * Arguments
#if defined key_agrif   
      INTEGER               :: kstp   ! ocean time-step index
#else
      INTEGER, INTENT( in ) :: kstp   ! ocean time-step index
#endif      

      !! * local declarations
      INTEGER ::   indic    ! error indicator if < 0
      !! ---------------------------------------------------------------------

#if defined key_agrif
      kstp = nit000 + Agrif_Nb_Step()
!      IF ( Agrif_Root() .and. lwp) Write(*,*) '---'
!      IF (lwp) Write(*,*) 'Grid Number',Agrif_Fixed(),' time step ',kstp
#endif   
      indic = 1                    ! reset to no error condition

      adatrj = adatrj + rdt/86400._wp

      CALL day( kstp )             ! Calendar

      CALL rst_opn( kstp )         ! Open the restart file

      !>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      ! Update data, open boundaries and Forcings
      !<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

      IF( lk_dtatem  )   CALL dta_tem( kstp )         ! update 3D temperature data

      IF( lk_dtasal  )   CALL dta_sal( kstp )         ! Salinity data

      IF( lk_dtasst  )   CALL dta_sst( kstp )         ! Sea Surface Temperature data

      IF( lk_dtasss  )   CALL dta_sss( kstp )         ! Sea Surface Salinity data

      IF( lk_obc     )   CALL obc_dta( kstp )         ! update dynamic and tracer data at open boundaries

      IF( lk_obc     )   CALL obc_rad( kstp )         ! compute phase velocities at open boundaries

      IF( .NOT. lk_core )    CALL tau( kstp )         ! wind stress

                         CALL flx_rnf( kstp )         ! runoff data

                         CALL flx( kstp )             ! heat and freshwater fluxes

      IF( lk_ice_lim )   CALL ice_stp( kstp )         ! sea-ice model (Update stress & fluxes)

                         CALL oce_sbc( kstp )         ! ocean surface boudaries

      IF( ln_fwb     )   CALL flx_fwb( kstp )         ! freshwater budget

      IF( nclosea == 1 ) CALL flx_clo( kstp )         ! closed sea in the domain (update freshwater fluxes)

      IF( kstp == nit000 ) THEN 
         IF( ninist == 1 ) THEN                       ! Output the initial state and forcings
            CALL dia_wri_state( 'output.init' )
         ENDIF
      ENDIF

      IF(ln_ctl) THEN         ! print mean trends (used for debugging)
         CALL prt_ctl(tab2d_1=emp    , clinfo1=' emp  -   : ', mask1=tmask, ovlap=1)
         CALL prt_ctl(tab2d_1=emps   , clinfo1=' emps -   : ', mask1=tmask, ovlap=1)
         CALL prt_ctl(tab2d_1=qt     , clinfo1=' qt   -   : ', mask1=tmask, ovlap=1)
         CALL prt_ctl(tab2d_1=qsr    , clinfo1=' qsr  -   : ', mask1=tmask, ovlap=1)
         CALL prt_ctl(tab2d_1=runoff , clinfo1=' runoff   : ', mask1=tmask, ovlap=1)
         CALL prt_ctl(tab3d_1=tmask  , clinfo1=' tmask    : ', mask1=tmask, ovlap=1, kdim=jpk)
         CALL prt_ctl(tab3d_1=tn     , clinfo1=' sst  -   : ', mask1=tmask, ovlap=1, kdim=1)
         CALL prt_ctl(tab3d_1=sn     , clinfo1=' sss  -   : ', mask1=tmask, ovlap=1, kdim=1)
         CALL prt_ctl(tab2d_1=taux   , clinfo1=' tau  - x : ', mask1=umask, &
            &         tab2d_2=tauy   , clinfo2='      - y : ', mask2=vmask,ovlap=1)
      ENDIF


      !>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      ! Ocean physics update
      !<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
      !-----------------------------------------------------------------------
      !  VERTICAL PHYSICS
      !-----------------------------------------------------------------------
      ! N.B. ua, va, ta, sa arrays are used as workspace in this section
      !-----------------------------------------------------------------------

                       CALL bn2( tb, sb, rn2 )              ! before Brunt-Vaisala frequency
      
      !                                                     ! Vertical eddy viscosity and diffusivity coefficients
      IF( lk_zdfric )   CALL zdf_ric( kstp )                       ! Richardson number dependent Kz
#if defined key_mpp_omp
      IF( lk_zdftke )   CALL zdf_tke_jki( kstp )                   ! TKE closure scheme for Kz - j-k-i loops
#else
      IF( lk_zdftke )   CALL zdf_tke( kstp )                       ! TKE closure scheme for Kz
#endif
      IF( lk_zdfkpp )   CALL zdf_kpp( kstp )                       ! KPP closure scheme for Kz

      IF( lk_zdfcst )   THEN                                       ! Constant Kz (reset avt, avm[uv] to the background value)
         avt (:,:,:) = avt0 * tmask(:,:,:)
         avmu(:,:,:) = avm0 * umask(:,:,:)
         avmv(:,:,:) = avm0 * vmask(:,:,:)
      ENDIF

      IF( cp_cfg == "orca" ) THEN                           ! ORCA: Reduce vertical mixing in some specific areas
         SELECT CASE ( jp_cfg )
            CASE ( 05 )                         ! ORCA R2 configuration
               avt  (:,:,2) = avt  (:,:,2) + 1.e-3 * upsrnfh(:,:)   ! increase diffusivity of rivers mouths
            CASE ( 025 )                         ! ORCA R025 configuration
               avt  (:,:,2) = avt  (:,:,2) + 2.e-3 * upsrnfh(:,:)   ! increase diffusivity of rivers mouths
         END SELECT
      ENDIF

      IF( ln_zdfevd )   CALL zdf_evd( kstp )                 ! enhanced vertical eddy diffusivity

      IF( lk_zdfddm .AND. .NOT. lk_zdfkpp)   &
         &              CALL zdf_ddm( kstp )                 ! double diffusive mixing

                        CALL zdf_bfr( kstp )                 ! bottom friction

                        CALL zdf_mxl( kstp )                 ! mixed layer depth


      !-----------------------------------------------------------------------
      !  LATERAL PHYSICS
      !-----------------------------------------------------------------------
      ! N.B. ua, va, ta, sa arrays are used as workspace in this section
      !-----------------------------------------------------------------------

      IF( lk_ldfslp     )   CALL ldf_slp( kstp, rhd, rn2 )       ! before slope of the lateral mixing

#if defined key_traldf_c2d
      IF( lk_traldf_eiv )   CALL ldf_eiv( kstp )                 ! eddy induced velocity coefficient
#endif


#if defined key_passivetrc
      !>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      ! Passive Tracer Model
      !<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
      ! N.B. ua, va, ta, sa arrays are used as workspace in this section
      !-----------------------------------------------------------------------

                             CALL trc_stp( kstp, indic )            ! time-stepping

#endif


      !>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      ! Active tracers
      !<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
      ! N.B. ua, va arrays are used as workspace in this section
      !-----------------------------------------------------------------------

                             ta(:,:,:) = 0.e0               ! set tracer trends to zero
                             sa(:,:,:) = 0.e0

                             CALL tra_sbc    ( kstp )       ! surface boundary condition

      IF( ln_traqsr      )   CALL tra_qsr    ( kstp )       ! penetrative solar radiation qsr

      IF( lk_trabbc      )   CALL tra_bbc    ( kstp )       ! bottom heat flux

      IF( lk_trabbl_dif  )   CALL tra_bbl_dif( kstp )       ! diffusive bottom boundary layer scheme
      IF( lk_trabbl_adv  )   CALL tra_bbl_adv( kstp )       ! advective (and/or diffusive) bottom boundary layer scheme

      IF( lk_tradmp      )   THEN                           ! internal damping trends
                             CALL tra_dmp    ( kstp, 'TRA', jp_tem, tb, ta )      ! temperature
                             CALL tra_dmp    ( kstp, 'TRA', jp_sal, sb, sa )      ! salinity
      ENDIF

                             CALL tra_adv    ( kstp )       ! horizontal & vertical advection

      IF( n_cla == 1     )   CALL tra_cla    ( kstp )       ! Cross Land Advection (Update Hor. advection)

      IF( lk_zdfkpp )        CALL tra_kpp    ( kstp )       ! KPP non-local tracer fluxes

                             CALL tra_ldf    ( kstp )       ! lateral mixing
#if defined key_agrif
      IF(.NOT. Agrif_Root()) CALL Agrif_Sponge_tra( kstp )  ! tracers sponge
#endif
                             CALL tra_zdf    ( kstp )       ! vertical mixing

                             CALL tra_nxt( kstp )           ! tracer fields at next time step

      IF( ln_zdfnpc      )   CALL tra_npc( kstp )           ! update the new (t,s) fields by non
      !                                                     ! penetrative convective adjustment

      IF( ln_dynhpg_imp  ) THEN                             ! semi-implicit hpg
                               CALL eos( ta, sa, rhd, rhop )          ! Time-filtered in situ density used in dynhpg module
         IF( ln_zps    )       CALL zps_hde( kstp, ta, sa, rhd,   &   ! Partial steps: time filtered hor. gradient
            &                                     gtu, gsu, gru,  &   ! of t, s, rd at the bottom ocean level
            &                                     gtv, gsv, grv )
      ELSE                                                  ! centered hpg (default case)
                               CALL eos( tb, sb, rhd, rhop )          ! now (swap=before) in situ density for dynhpg module
         IF( ln_zps    )       CALL zps_hde( kstp, tb, sb, rhd,   &   ! Partial steps: now horizontal gradient
            &                                     gtu, gsu, gru,  &   ! of t, s, rd at the bottom ocean level
            &                                     gtv, gsv, grv )
      ENDIF

      !>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      ! Dynamics
      !<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
      ! N.B. ta, sa arrays are used as workspace in this section 
      !-----------------------------------------------------------------------


                               ua(:,:,:) = 0.e0               ! set dynamics trends to zero
                               va(:,:,:) = 0.e0

                               CALL dyn_adv( kstp )           ! advection (vector or flux form)

                               CALL dyn_vor( kstp )           ! vorticity term including Coriolis

                               CALL dyn_ldf( kstp )           ! lateral mixing
#if defined key_agrif
      IF(.NOT. Agrif_Root())   CALL Agrif_Sponge_dyn( kstp )  ! momemtum sponge
#endif
                               CALL dyn_hpg( kstp )           ! horizontal gradient of Hydrostatic pressure

                               CALL dyn_zdf( kstp )           ! vertical diffusion

      IF( lk_dynspg_rl ) THEN
         IF( lk_obc    )       CALL obc_spg( kstp )           ! surface pressure gradient at open boundaries
      ENDIF
                       indic=0
!i bug lbc sur emp
      CALL lbc_lnk( emp, 'T', 1. )
!i
                               CALL dyn_spg( kstp, indic )    ! surface pressure gradient

                               CALL dyn_nxt( kstp )           ! lateral velocity at next time step

      IF( lk_vvl )             CALL dom_vvl                   ! vertical mesh at next time step


      !>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      ! Computation of diagnostic variables
      !<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
      ! N.B. ua, va, ta, sa arrays are used as workspace in this section
      !-----------------------------------------------------------------------

                       CALL oc_fz_pt                        ! ocean surface freezing temperature

                       CALL div_cur( kstp )                 ! Horizontal divergence & Relative vorticity

      IF( n_cla == 1 ) CALL div_cla( kstp )                 ! Cross Land Advection (Update Hor. divergence)

                       CALL wzv( kstp )                     ! Vertical velocity



      !>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      ! Control, and restarts
      !<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
      ! N.B. ua, va, ta, sa arrays are used as workspace in this section
      !-----------------------------------------------------------------------
      !                                                     ! Time loop: control and print
                                 CALL stp_ctl( kstp, indic )
      IF( indic < 0          )   CALL ctl_stop( 'step: indic < 0' )

      IF( kstp == nit000     )   CALL iom_close( numror )             ! close input  ocean restart file
      IF( lrst_oce           )   CALL rst_write  ( kstp )             ! write output ocean restart file
      IF( lk_obc             )   CALL obc_rst_wri( kstp )             ! write open boundary restart file

      !>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      ! diagnostics and outputs
      !<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
      ! N.B. ua, va, ta, sa arrays are used as workspace in this section
      !-----------------------------------------------------------------------

      IF ( nstop == 0 ) THEN                                ! Diagnostics
         IF( lk_floats  )   CALL flo_stp( kstp )                 ! drifting Floats
         IF( lk_trddyn  )   CALL trd_dwr( kstp )                 ! trends: dynamics 
         IF( lk_trdtra  )   CALL trd_twr( kstp )                 ! trends: active tracers
         IF( lk_trdmld  )   CALL trd_mld( kstp )                 ! trends: Mixed-layer 
         IF( lk_trdvor  )   CALL trd_vor( kstp )                 ! trends: vorticity budget
         IF( lk_diaspr  )   CALL dia_spr( kstp )                 ! Surface pressure diagnostics
         IF( lk_diahth  )   CALL dia_hth( kstp )                 ! Thermocline depth (20 degres isotherm depth)
         IF( lk_diagap  )   CALL dia_gap( kstp )                 ! basin averaged diagnostics
         IF( lk_diahdy  )   CALL dia_hdy( kstp )                 ! dynamical heigh diagnostics
         IF( lk_diafwb  )   CALL dia_fwb( kstp )                 ! Fresh water budget diagnostics
         IF( ln_diaptr  )   CALL dia_ptr( kstp )                 ! Poleward TRansports diagnostics

         !                                                 ! Outputs
                            CALL dia_wri    ( kstp, indic )      ! ocean model: outputs
      ENDIF

      !>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      ! Coupled mode
      !<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

      IF( lk_cpl    )   CALL cpl_stp( kstp )                 ! coupled mode : field exchanges
      !
   END SUBROUTINE stp

   !!======================================================================
END MODULE step
